@@ -69,6 +69,7 @@ U_NL_END = re.compile(r'(?:{0})$'.format(U_NEWLINE.pattern))
 
 try:
     import importlib_metadata
+
     __version__ = importlib_metadata.version('path.py')
 except Exception:
     __version__ = 'unknown'
@@ -96,6 +97,7 @@ def simple_cache(func):
             return saved_results[module]
         saved_results[module] = func(cls, module)
         return saved_results[module]
+
     return wrapper
 
 
@@ -109,12 +111,14 @@ class multimethod(object):
     Acts like a classmethod when invoked from the class and like an
     instancemethod when invoked from the instance.
     """
+
     def __init__(self, func):
         self.func = func
 
     def __get__(self, instance, owner):
         return (
-            functools.partial(self.func, owner) if instance is None
+            functools.partial(self.func, owner)
+            if instance is None
             else functools.partial(self.func, owner, instance)
         )
 
@@ -319,7 +323,9 @@ class Path(str):
         return self._next_class(drive)
 
     parent = property(
-        dirname, None, None,
+        dirname,
+        None,
+        None,
         """ This path's parent directory, as a new Path object.
 
         For example,
@@ -327,17 +333,21 @@ class Path(str):
         Path('/usr/local/lib')``
 
         .. seealso:: :meth:`dirname`, :func:`os.path.dirname`
-        """)
+        """,
+    )
 
     name = property(
-        basename, None, None,
+        basename,
+        None,
+        None,
         """ The name of this file or directory without the full path.
 
         For example,
         ``Path('/usr/local/lib/libpython.so').name == 'libpython.so'``
 
         .. seealso:: :meth:`basename`, :func:`os.path.basename`
-        """)
+        """,
+    )
 
     def splitpath(self):
         """ p.splitpath() -> Return ``(p.parent, p.name)``.
@@ -493,9 +503,7 @@ class Path(str):
         .. seealso:: :meth:`files`, :meth:`dirs`
         """
         match = matchers.load(match)
-        return list(filter(match, (
-            self / child for child in os.listdir(self)
-        )))
+        return list(filter(match, (self / child for child in os.listdir(self))))
 
     def dirs(self, *args, **kwargs):
         """ D.dirs() -> List of this directory's subdirectories.
@@ -535,6 +543,7 @@ class Path(str):
         reports the error via :func:`warnings.warn()`), and ``'ignore'``.
         `errors` may also be an arbitrary callable taking a msg parameter.
         """
+
         class Handlers:
             def strict(msg):
                 raise
@@ -579,20 +588,12 @@ class Path(str):
     def walkdirs(self, *args, **kwargs):
         """ D.walkdirs() -> iterator over subdirs, recursively.
         """
-        return (
-            item
-            for item in self.walk(*args, **kwargs)
-            if item.isdir()
-        )
+        return (item for item in self.walk(*args, **kwargs) if item.isdir())
 
     def walkfiles(self, *args, **kwargs):
         """ D.walkfiles() -> iterator over files in D, recursively.
         """
-        return (
-            item
-            for item in self.walk(*args, **kwargs)
-            if item.isfile()
-        )
+        return (item for item in self.walk(*args, **kwargs) if item.isfile())
 
     def fnmatch(self, pattern, normcase=None):
         """ Return ``True`` if `self.name` matches the given `pattern`.
@@ -706,8 +707,9 @@ class Path(str):
         with self.open(mode='r', encoding=encoding, errors=errors) as f:
             return U_NEWLINE.sub('\n', f.read())
 
-    def write_text(self, text, encoding=None, errors='strict',
-                   linesep=os.linesep, append=False):
+    def write_text(
+        self, text, encoding=None, errors='strict', linesep=os.linesep, append=False
+    ):
         r""" Write the given text to this file.
 
         The default behavior is to overwrite any existing file;
@@ -799,8 +801,9 @@ class Path(str):
         """
         return self.text(encoding, errors).splitlines(retain)
 
-    def write_lines(self, lines, encoding=None, errors='strict',
-                    linesep=os.linesep, append=False):
+    def write_lines(
+        self, lines, encoding=None, errors='strict', linesep=os.linesep, append=False
+    ):
         r""" Write the given lines of text to this file.
 
         By default this overwrites any existing file at this path.
@@ -844,8 +847,7 @@ class Path(str):
                     pattern = U_NL_END if isUnicode else NL_END
                     line = pattern.sub('', line) + linesep
                 if isUnicode:
-                    line = line.encode(
-                        encoding or sys.getdefaultencoding(), errors)
+                    line = line.encode(encoding or sys.getdefaultencoding(), errors)
                 f.write(line)
 
     def read_md5(self):
@@ -929,46 +931,59 @@ class Path(str):
         return self.module.getatime(self)
 
     atime = property(
-        getatime, None, None,
+        getatime,
+        None,
+        None,
         """ Last access time of the file.
 
         .. seealso:: :meth:`getatime`, :func:`os.path.getatime`
-        """)
+        """,
+    )
 
     def getmtime(self):
         """ .. seealso:: :attr:`mtime`, :func:`os.path.getmtime` """
         return self.module.getmtime(self)
 
     mtime = property(
-        getmtime, None, None,
+        getmtime,
+        None,
+        None,
         """ Last-modified time of the file.
 
         .. seealso:: :meth:`getmtime`, :func:`os.path.getmtime`
-        """)
+        """,
+    )
 
     def getctime(self):
         """ .. seealso:: :attr:`ctime`, :func:`os.path.getctime` """
         return self.module.getctime(self)
 
     ctime = property(
-        getctime, None, None,
+        getctime,
+        None,
+        None,
         """ Creation time of the file.
 
         .. seealso:: :meth:`getctime`, :func:`os.path.getctime`
-        """)
+        """,
+    )
 
     def getsize(self):
         """ .. seealso:: :attr:`size`, :func:`os.path.getsize` """
         return self.module.getsize(self)
 
     size = property(
-        getsize, None, None,
+        getsize,
+        None,
+        None,
         """ Size of the file, in bytes.
 
         .. seealso:: :meth:`getsize`, :func:`os.path.getsize`
-        """)
+        """,
+    )
 
     if hasattr(os, 'access'):
+
         def access(self, mode):
             """ Return ``True`` if current user has access to this path.
 
@@ -1003,7 +1018,8 @@ class Path(str):
         .. seealso:: :attr:`owner`
         """
         desc = win32security.GetFileSecurity(
-            self, win32security.OWNER_SECURITY_INFORMATION)
+            self, win32security.OWNER_SECURITY_INFORMATION
+        )
         sid = desc.GetSecurityDescriptorOwner()
         account, domain, typecode = win32security.LookupAccountSid(None, sid)
         return domain + '\\' + account
@@ -1029,12 +1045,16 @@ class Path(str):
         get_owner = __get_owner_not_implemented
 
     owner = property(
-        get_owner, None, None,
+        get_owner,
+        None,
+        None,
         """ Name of the owner of this file or directory.
 
-        .. seealso:: :meth:`get_owner`""")
+        .. seealso:: :meth:`get_owner`""",
+    )
 
     if hasattr(os, 'statvfs'):
+
         def statvfs(self):
             """ Perform a ``statvfs()`` system call on this path.
 
@@ -1043,6 +1063,7 @@ class Path(str):
             return os.statvfs(self)
 
     if hasattr(os, 'pathconf'):
+
         def pathconf(self, name):
             """ .. seealso:: :func:`os.pathconf` """
             return os.pathconf(self, name)
@@ -1189,6 +1210,7 @@ class Path(str):
     # --- Links
 
     if hasattr(os, 'link'):
+
         def link(self, newpath):
             """ Create a hard link at `newpath`, pointing to this file.
 
@@ -1198,6 +1220,7 @@ class Path(str):
             return self._next_class(newpath)
 
     if hasattr(os, 'symlink'):
+
         def symlink(self, newlink=None):
             """ Create a symbolic link at `newlink`, pointing here.
 
@@ -1212,6 +1235,7 @@ class Path(str):
             return self._next_class(newlink)
 
     if hasattr(os, 'readlink'):
+
         def readlink(self):
             """ Return the path to which this symbolic link points.
 
@@ -1262,11 +1286,14 @@ class Path(str):
     cd = chdir
 
     def merge_tree(
-            self, dst, symlinks=False,
-            *,
-            update=False,
-            copy_function=shutil.copy2,
-            ignore=lambda dir, contents: []):
+        self,
+        dst,
+        symlinks=False,
+        *,
+        update=False,
+        copy_function=shutil.copy2,
+        ignore=lambda dir, contents: []
+    ):
         """
         Copy entire contents of self to dst, overwriting existing
         contents in dst with those in self.
@@ -1285,8 +1312,7 @@ class Path(str):
 
         if update:
             warnings.warn(
-                "Update is deprecated; "
-                "use copy_function=only_newer(shutil.copy2)",
+                "Update is deprecated; " "use copy_function=only_newer(shutil.copy2)",
                 DeprecationWarning,
                 stacklevel=2,
             )
@@ -1320,11 +1346,13 @@ class Path(str):
     # --- Special stuff from os
 
     if hasattr(os, 'chroot'):
+
         def chroot(self):
             """ .. seealso:: :func:`os.chroot` """
             os.chroot(self)
 
     if hasattr(os, 'startfile'):
+
         def startfile(self):
             """ .. seealso:: :func:`os.startfile` """
             os.startfile(self)
@@ -1334,8 +1362,13 @@ class Path(str):
     # http://www.zopatista.com/python/2013/11/26/inplace-file-rewriting/
     @contextlib.contextmanager
     def in_place(
-            self, mode='r', buffering=-1, encoding=None, errors=None,
-            newline=None, backup_extension=None,
+        self,
+        mode='r',
+        buffering=-1,
+        encoding=None,
+        errors=None,
+        newline=None,
+        backup_extension=None,
     ):
         """
         A context in which a file may be re-written in-place with
@@ -1376,15 +1409,22 @@ class Path(str):
             pass
         os.rename(self, backup_fn)
         readable = io.open(
-            backup_fn, mode, buffering=buffering,
-            encoding=encoding, errors=errors, newline=newline,
+            backup_fn,
+            mode,
+            buffering=buffering,
+            encoding=encoding,
+            errors=errors,
+            newline=newline,
         )
         try:
             perm = os.fstat(readable.fileno()).st_mode
         except OSError:
             writable = open(
-                self, 'w' + mode.replace('r', ''),
-                buffering=buffering, encoding=encoding, errors=errors,
+                self,
+                'w' + mode.replace('r', ''),
+                buffering=buffering,
+                encoding=encoding,
+                errors=errors,
                 newline=newline,
             )
         else:
@@ -1393,8 +1433,11 @@ class Path(str):
                 os_mode |= os.O_BINARY
             fd = os.open(self, os_mode, perm)
             writable = io.open(
-                fd, "w" + mode.replace('r', ''),
-                buffering=buffering, encoding=encoding, errors=errors,
+                fd,
+                "w" + mode.replace('r', ''),
+                buffering=buffering,
+                encoding=encoding,
+                errors=errors,
                 newline=newline,
             )
             try:
@@ -1467,15 +1510,14 @@ def only_newer(copy_func):
     Wrap a copy function (like shutil.copy2) to return
     the dst if it's newer than the source.
     """
+
     @functools.wraps(copy_func)
     def wrapper(src, dst, *args, **kwargs):
-        is_newer_dst = (
-            dst.exists()
-            and dst.getmtime() >= src.getmtime()
-        )
+        is_newer_dst = dst.exists() and dst.getmtime() >= src.getmtime()
         if is_newer_dst:
             return dst
         return copy_func(src, dst, *args, **kwargs)
+
     return wrapper
 
 
@@ -1496,8 +1538,7 @@ class SpecialResolver(object):
         not args and kwargs.setdefault('appname', None)
 
         vars(self).update(
-            path_class=path_class,
-            wrapper=appdirs.AppDirs(*args, **kwargs),
+            path_class=path_class, wrapper=appdirs.AppDirs(*args, **kwargs)
         )
 
     def __getattr__(self, scope):
@@ -1518,6 +1559,7 @@ class Multi:
     """
     A mix-in for a Path which may contain multiple Path separated by pathsep.
     """
+
     @classmethod
     def for_class(cls, path_cls):
         name = 'Multi' + path_cls.__name__
@@ -1538,11 +1580,7 @@ class Multi:
         """
         Multi-subclasses should use the parent class
         """
-        return next(
-            class_
-            for class_ in cls.__mro__
-            if not issubclass(class_, Multi)
-        )
+        return next(class_ for class_ in cls.__mro__ if not issubclass(class_, Multi))
 
 
 class TempDir(Path):
@@ -1596,8 +1634,10 @@ def _multi_permission_mask(mode):
     >>> _multi_permission_mask('a=r,u+w')(0) == 0o644
     True
     """
+
     def compose(f, g):
         return lambda *args, **kwargs: g(f(*args, **kwargs))
+
     return functools.reduce(compose, map(_permission_mask, mode.split(',')))
 
 
@@ -1666,9 +1706,7 @@ def _permission_mask(mode):
 class CaseInsensitivePattern(matchers.CaseInsensitive):
     def __init__(self, value):
         warnings.warn(
-            "Use matchers.CaseInsensitive instead",
-            DeprecationWarning,
-            stacklevel=2,
+            "Use matchers.CaseInsensitive instead", DeprecationWarning, stacklevel=2
         )
         super(CaseInsensitivePattern, self).__init__(value)
 
